@@ -21,6 +21,8 @@ import sys
 import signal
 import merlin.fluent
 import merlin.resource_request
+import merlin.deployment_mode
+import merlin.autoscaling
 from merlin.version import VERSION as __version__
 
 
@@ -43,7 +45,7 @@ set_model = merlin.fluent.set_model
 active_model = merlin.fluent.active_model
 
 # Model Version
-new_model_version = merlin.fluent.new_model_version
+new_model_version = merlin.fluent.new_model_version  # type:ignore
 log_param = merlin.fluent.log_param
 log_metric = merlin.fluent.log_metric
 set_tag = merlin.fluent.set_tag
@@ -75,7 +77,9 @@ list_model_endpoints = merlin.fluent.list_model_endpoints
 
 # Definitions
 ResourceRequest = merlin.resource_request.ResourceRequest
-
+DeploymentMode = merlin.deployment_mode.DeploymentMode
+AutoscalingPolicy = merlin.autoscaling.AutoscalingPolicy
+MetricsType = merlin.autoscaling.MetricsType
 # Batch
 create_prediction_job = merlin.fluent.create_prediction_job
 
@@ -89,7 +93,7 @@ __all__ = [
     "log_artifact", "log_pyfunc_model", "log_pytorch_model", "log_model",
     "deploy", "undeploy",
     "set_traffic", "serve_traffic",
-    "ResourceRequest",
+    "ResourceRequest", "DeploymentMode", "AutoscalingPolicy", "MetricsType",
     "create_prediction_job"
 ]
 
